shared

package
v1.32.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 12, 2026 License: MIT Imports: 3 Imported by: 0

Documentation

Overview

Package shared holds format helpers for variable subcommands.

Index

Constants

const SecuredPlaceholder = "<secured>"

SecuredPlaceholder is rendered in TTY tables in place of a secured variable's value.

Variables

This section is empty.

Functions

func DisplayEnvVariableValue

func DisplayEnvVariableValue(v backend.EnvVariable) string

DisplayEnvVariableValue redacts secured env variable values for TTY output.

func DisplayVariableValue

func DisplayVariableValue(v backend.PipelineVariable) string

DisplayVariableValue redacts secured pipeline variable values for TTY output.

func EnvVariableFields

func EnvVariableFields(f *factory.Factory, jsonFields, jqExpr string) *format.Printer[backend.EnvVariable]

EnvVariableFields constructs the formatter for deployment scope variable lists (EnvVariable). Secured values are redacted in both TTY and JSON paths.

func VariableFields

func VariableFields(f *factory.Factory, jsonFields, jqExpr string) *format.Printer[backend.PipelineVariable]

VariableFields constructs the formatter for repository and workspace scope variable lists (PipelineVariable). Secured values are redacted via DisplayVariableValue in both TTY and JSON output paths.

Types

This section is empty.

Jump to