webhook

package
v1.19.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 7, 2026 License: MIT Imports: 6 Imported by: 0

Documentation

Overview

Package webhook is the root of the `webhook` subcommand tree.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewCmdWebhook

func NewCmdWebhook(f *factory.Factory) *cobra.Command

NewCmdWebhook builds the root `webhook` command. Subcommands live in their own subpackages (gh-CLI style).

Types

This section is empty.

Directories

Path Synopsis
internal
cmdtest
Package cmdtest holds shared test fixtures for webhook subcommand tests.
Package cmdtest holds shared test fixtures for webhook subcommand tests.
Package shared holds helpers used across webhook subcommands.
Package shared holds helpers used across webhook subcommands.

Jump to