Documentation
¶
Overview ¶
Package git wraps internal/run.Runner to provide git-specific operations.
Index ¶
- type Git
- func (g *Git) Checkout(branch string) error
- func (g *Git) Clone(url, dir string) error
- func (g *Git) CommitsAhead(base string) (int, error)
- func (g *Git) CurrentBranch() (string, error)
- func (g *Git) Fetch(remote, branch string) error
- func (g *Git) HasUncommittedChanges() (bool, error)
- func (g *Git) RemoteURL(name string) (string, error)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Git ¶
type Git struct {
// contains filtered or unexported fields
}
Git provides git operations via the Runner.
func (*Git) CommitsAhead ¶
CommitsAhead returns number of commits in current branch ahead of base.
func (*Git) CurrentBranch ¶
CurrentBranch returns the name of the current branch.
func (*Git) HasUncommittedChanges ¶
HasUncommittedChanges returns true if the working tree is dirty.
Click to show internal directories.
Click to hide internal directories.